<?php
/*
Plugin Name: Dynamic Background
Plugin URI:  http://wordpooldesign.co.uk/wordpress/dynamicbg
Description: Continuously and gently changes color of background and/or pictures with transparent areas on selected pages.
Version: 1.0
*/
//defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

function wordpoolbg_admin_bar() {
	global $wp_admin_bar;

	$wp_admin_bar->add_menu( array(
		'id'    => 'wordpool_bg',
		'title' => 'Dynamic Background',
		'href'  => admin_url().'themes.php?page=wordpoolbg',
		'parent'=>'site-name'
	));
}
if( !is_admin() ){
	add_action( 'wp_before_admin_bar_render', 'wordpoolbg_admin_bar' );
}


add_action('wp_enqueue_scripts','enqueue_wordpool_background_colour');
function enqueue_wordpool_background_colour(){
	wp_enqueue_script('jquery');
	wp_enqueue_script('getbg', plugins_url().'/dynamic-background/getbg.js');
}

add_action('wp_head','run_wordpool_background_colour');

function run_wordpool_background_colour(){
	/*	This function writes the chosen values into hidden divs so that the javascript colour changer knows how to
		behave.It should only do it if the page matches the page id or blog found in the stored values. 
		It needs to know whether to manipulate the background or the picture backgrounds.
	*/
	$pic=0;
	$bg=0;
	$options = get_option( 'wordpool-background-options');
	if($options){
		$pagelist=$options['pagelist']; //list of pages that will get the effect
		$catlist=$options['catlist']; //List of post categories that will get the effect (currently only 'blog'
		$picpagelist=$options['picpagelist'];//list of pages where the puctures will be targetted
		$piccatlist=$options['piccatlist']; //List of post categories for pictures (currently only 'blog'
		$body_classes=get_body_class();
		foreach($body_classes as $body_class){
			foreach((array)$catlist as $catstored){
				if($catstored==$body_class){
					$bg=1;
				}
			}
			foreach((array)$pagelist as $stored_page_id){
				$full="page-id-".$stored_page_id;
				if($full==$body_class){
					$bg=1;
				}
			}
			foreach((array)$piccatlist as $piccatstored){
				if($piccatstored==$body_class){
					$pic=1;
				}
			}
			foreach((array)$picpagelist as $pic_stored_page_id){
				$full="page-id-".$pic_stored_page_id;
				if($full==$body_class){
					$pic=1;
				}
			}
		}
		//echo "go is $bg or $pic";
		if($bg || $pic){
			$bgc=get_background_color();  //Standard WPress functions.
			if(!$bgc){
				$bgc="CCFFFF";
			}
			$useh=$options['useh'];			// modify hue
			$uses=$options['uses'];			// modify saturation
			$usel=$options['usel'];			// modify lightness
			$hT=$options['hT'];				// hue period
			$sT=$options['sT'];				// saturation period
			$lT=$options['lT'];				// lightness period
			$srange=$options['srange'];	//saturaion range (up, down or both
			$lrange=$options['lrange'];	//saturaion range (up, down or both
			
						
			//Embed the colour part of this data in the page itself + what should  be altered
			print "\n<div id=\"wordpool-background-info\" style=\"display:none\">$bgc,$useh,$uses,$usel,$hT,$sT,$lT,$srange,$lrange,$bg,$pic</div>\n";
			

			//Create a white background for any images so that they can be manipulated
			if($pic){
				print "<style>";
				print "img{background-color:#ffffff;}";
				print "</style>";
			}
		}
	}
}


//////////////////////////////////////////////////////////////////////////////////

add_action('admin_menu', 'wordpool_background_menu');
function wordpool_background_menu() {
	add_theme_page('bgrotate', 'Dynamic Background', 'edit_theme_options', 'wordpoolbg', 'wordpool_background');
}

function wordpool_background(){
	//This function provides the user settings page
	$options = get_option( 'wordpool-background-options');
	if(!$options){ //This is a first time set-up so will only run rarely.
		$options=array(
			'useh' => '0',
			'uses' => '0',
			'usel' => '0',
			'hT'   => '0',
			'sT'   => '0',
			'lT'   => '0',
			'srange' => 'b',
			'lrange' => 'b',
			'catlist' => array(),
			'pagelist' => array(),
			'piccatlist'=> array(),
			'picpagelist'=> array()
		);
		update_option( 'wordpool-background-options', $options );
	}
	$hidden_field_name = 'wordpool-background-submit-hidden';

	$errmsg=""; //Start by assuming no errors
	$newvals=false;
	// See if the user has posted us some information
	// If they did, this hidden field will be set to 'Y'
	if( isset($_POST[ $hidden_field_name ]) && $_POST[ $hidden_field_name ] == 'Y' ) {
		$newvals=true;
		// Read their posted value, sanitise, (required by Wordpress even if it doesn't matter what 
		//	they say) and set an easier to read variable
		
		//==============================================
		// Decide to use H, S, L in the settings...
		if($_POST[ 'useh' ] == 1 ) { $useh=1; } else { $useh=0; }
		if($_POST[ 'uses' ] == 1 ) { $uses=1; } else { $uses=0; }
		if($_POST[ 'usel' ] == 1 ) { $usel=1; } else { $usel=0; }
		
		//==============================================
		// Set the times if  H/S/L are in use
		if($useh){
			if(!is_numeric($_POST[ 'hT' ]) || $_POST[ 'hT' ]<1){
				
				$errmsg.="Bad hue cycle time ()<br>";
			}	
			else {
				$hT  = $_POST[ 'hT' ];
			}
		}
		
		if($uses){
			if(!is_numeric($_POST[ 'sT' ]) || $_POST[ 'sT' ]<1){
				$errmsg.="Bad saturation cycle time<br>";
			}
			else{
				$sT  = $_POST[ 'sT' ];
			}
		}
		if($usel){
			if(!is_numeric($_POST['lT']) || $_POST[ 'lT' ]<1){
				$errmsg.="Bad lightness cycle time<br>";
			}	
			else{
				$lT  = $_POST[ 'lT' ];
			}
		}
		//================================================
		//Pick the ranges for S and L.  Only up down and both (u, d, b are allowed)
		if($_POST[ 'srange' ]=='u' || $_POST[ 'srange' ]=='d' || $_POST[ 'srange' ]=='b'){
			$srange = $_POST[ 'srange' ];
		}
		else {
			$srange=="";
		}
		if($_POST[ 'lrange' ]=='u' || $_POST[ 'lrange' ]=='d' || $_POST[ 'lrange' ]=='b'){
			$lrange = $_POST[ 'lrange' ];
		}
		else {
			$lrange="";
		}
		//================================================
		// Check the lists of pages for backgrounds and pictures for posts. 
		// These sstarted as cateogries but are now restricted to just the 
		// blog page
		if($_POST[ 'cbpost' ][0] == 'blog'){
			$catlist= $_POST[ 'cbpost' ];
		}
		else{
			($catlist="");
		}
		if($_POST[ 'cbpicpost' ][0] == 'blog'){
			$piccatlist= $_POST[ 'cbpicpost' ];
		}
		else{
			$piccatlist= "";
		}
		//=============================================
		// These two posts are arrays of numbers - I think that's all we can check for
		if(is_array($_POST[ 'cbpage' ])){
			foreach($_POST[ 'cbpage' ] as $page_id){
				if(!is_numeric($page_id)){
					$errmsg.="Background page ID problem ($page_id)<br>";
				}
			}
			if(!$errmsg){
				$pagelist= $_POST[ 'cbpage' ];
			}
		}
		
		if(is_array($_POST[ 'cbpicpage' ])){
			foreach($_POST[ 'cbpicpage' ] as $page_id){
				if(!is_numeric($page_id)){
					$errmsg.="Picture in page ID problem ($page_id)<br>";
				}
			}
			if(!$errmsg){
				$picpagelist= $_POST[ 'cbpicpage' ];
			}
		}
		

		
		//echo "DEBUG IN background params = $useh, $uses, $usel $hT, $sT, $lT, $srange, $lrange";
		//echo "picpagelist follows<br>";
		//var_dump($picpagelist);
		
		
		//==========================================================
		//If its all OK, rewite data to the data base
		if(!$errmsg){ 
			$options=array(
				'useh' => $useh,
				'uses' => $uses,
				'usel' => $usel,
				'hT'   => $hT,
				'sT'   => $sT,
				'lT'   => $lT,
				'srange' => $srange,
				'lrange' => $lrange,
				'catlist' => $catlist,
				'pagelist'=> $pagelist,
				'piccatlist' => $piccatlist,
				'picpagelist' => $picpagelist
			);
			//echo "<br>DEBUG to db... ";
			//var_dump($options['picpagelist']);
			update_option( 'wordpool-background-options', $options );
		}
	}
	//Get the values from the database which are either updated or not as required
	$options = get_option( 'wordpool-background-options' );	
	
	$useh=$options['useh'];
	$uses=$options['uses'];
	$usel=$options['usel'];
	$hT=$options['hT'];
	$sT=$options['sT'];
	$lT=$options['lT'];
	$srange=$options['srange'];
	$lrange=$options['lrange'];
	$catlist=$options['catlist'];
	$pagelist=$options['pagelist'];
	$piccatlist=$options['piccatlist'];
	$picpagelist=$options['picpagelist'];
	//echo "<br>DEBUG picpagelist from db... <br>";
	//var_dump($picpagelist);	
	
	//Sort out check boxes:
	$hcheck=""; $scheck=""; $lcheck="";
	if($useh){$hcheck="checked";}
	if($uses){$scheck="checked";}
	if($usel){$lcheck="checked";}
	
	//need to sort the radio buttons 
	$su=""; $sd=""; $sb=""; $lu=""; $ld=""; $lb="";
	switch ($srange) {
		case "u":
			$su="checked";
		break;
		case "d":
			$sd="checked";
		break;
		case "b":
			$sb="checked";
		break;
	}
	switch ($lrange) {
		case "u":
			$lu="checked";
		break;
		case "d":
			$ld="checked";
		break;
		case "b":
			$lb="checked";
		break;
	}	
			
			
 // Now display the settings editing screen

    print '<div class="wrap">';

    // header

    echo "<h2>Dynamic Background Color</h2>";
	 echo "<p>To use this plugin, first set a custom background color from Dashboard > Appearance > Background. If your theme does not support custom background colours, <span style=\"background-color:#ccffff; color:#000000\"> #CCFFFF; will be used</span></p>";
	 echo '<p>For most themes, "Background" is the area outside the main content and may not be visible on mobile devices where the content fills the screen completely.  On a few themes, background can be seen behind the main content.</p>';
	 echo '<p>If your theme supports a background image and that image includes transparent areas, the changing colours will show through.</p>';
	 echo '<p>If you choose "Pictures in page" and any images on the page have transparent areas, the changing colours will show through.</p>';
	 echo "<p>Small cycle times will give big color steps and the effect will not be smooth. Cycle times must be 1 second or greater. 5-60 seconds give pleasant effects</p>";
	 echo "<p>You can set any combination of Hue, Saturation and Lightness.<br>Hue is the main color and if set by itself, the background color just cycles round the color wheel.<br>If you decide to vary the  Saturation and Lighness of the initial color, you can choose to make them go from the original value to their maximum and back (Up) or from their original value to minimum and back (Down).  If you choose 'Both', the original values are no longer relevant - the values vary between maximum and minimum</p>";

    // settings form
    
    ?>

   <form name="form1" method="post" action="">
   <input type="hidden" name="<?php echo $hidden_field_name; ?>" value="Y">



	<?php
   //find and offer the post categories in use. We are only going to use blog
   
   //$post_categories = get_categories();
   //Doesn't include "../wordpool-background-colour/Blog" so we'll add it
   //$extra['slug']="blog";
   //$extra['name']="Blog";
   // but post_categories is an array of objects!
   //$obj_extra=(object) $extra;
   
   //Add this to the top of the list
   //array_unshift($post_categories, $obj_extra);
   //var_dump($post_categories);
   //$op_cats="<input type=\"checkbox\" name=\"cbpost[]\" value=\"blog\">&nbsp;Blog<br>\n"; 
   
   if($catlist[0]=='blog'){
      $catchecked=" checked";
   }
   else{
      $catchecked="";
   }
   $op_cats="Blog&nbsp;<input type=\"checkbox\" name=\"cbpost[]\" value=\"blog\" $catchecked /><br>\n";
   
	if($piccatlist[0]=='blog'){
      $piccatchecked=" checked";
   }
   else{
      $piccatchecked="";
   }
   $op_piccats="&nbsp;<input type=\"checkbox\" name=\"cbpicpost[]\" value=\"blog\" $piccatchecked /><br>\n";
	
	
   
   //find and offer the pages in use
   
	$pageids=get_all_page_ids();
   //Start by inserting the blog with a different checkbox name
	$op_pages="\n".$op_cats;
	foreach ( $pageids as $pageid ) {
		$pagetitle=get_the_title( $pageid );
		$pagechecked="";
		foreach((array)$pagelist as $storedid){
         //echo("$pageid=$storedid?<br>");
			if($pageid==$storedid){
				$pagechecked=" checked";
			}
		}
		$op_pages.= "$pagetitle&nbsp;<input type=\"checkbox\" name=\"cbpage[]\" value=\"$pageid\" $pagechecked /><br>\n";
	}
 
	$op_picpages="\n".$op_piccats;
	foreach ( $pageids as $pageid ) {
		$picpagechecked="";
		foreach((array)$picpagelist as $storedid){
			if($pageid==$storedid){
				$picpagechecked=" checked";
			}
		}
		$op_picpages.= "&nbsp;<input type=\"checkbox\" name=\"cbpicpage[]\" value=\"$pageid\" $picpagechecked /><br>\n";
	}
 
  
 ?>


<table width=" " cellspacing="0" cellpadding="0">
  <tr>
    <td>&nbsp;</td>
    <td>&nbsp;</td>
    <th>Cycle time (S)</th>
    <th>&nbsp;Up&nbsp;</th>
    <th>&nbsp;Down&nbsp;</th>
    <th>&nbsp;Both</th>
  </tr>
  <tr>
    <th align="right">Hue&nbsp;</th>
    <td><input type="checkbox" name="useh" value="1" <?php print $hcheck; ?> /></td>
    <td align="center"><input type="text" name="hT" value="<?php echo $hT; ?>" size="12" /></td>
    <td align="center">-</td>
    <td align="center">-</td>
    <td align="center">-</td>
  </tr>
  <tr>
    <th align="right">Saturation&nbsp;</th>
    <td><input type="checkbox" name="uses" value="1" <?php print $scheck; ?> /></td>
    <td align="center"><input type="text" name="sT" value="<?php echo $sT; ?>" size="12" /></td>
    <td align="center"><input type="radio" name="srange" value="u" <?php print $su; ?> /></td>
    <td align="center"><input type="radio" name="srange" value="d" <?php print $sd; ?> /></td>
    <td align="center"><input type="radio" name="srange" value="b" <?php print $sb; ?> /></td>
  </tr>
  <tr>
    <th align="right">Lightness&nbsp;</th>
    <td><input type="checkbox" name="usel" value="1" <?php print $lcheck; ?> /></td>
    <td align="center"><input type="text" name="lT" value="<?php echo $lT ?>" size="12" /></td>
    <td align="center"><input type="radio" name="lrange"  value="u" <?php print $lu; ?>/></td>
    <td align="center"><input type="radio" name="lrange"  value="d" <?php print $ld; ?>/></td>
    <td align="center"><input type="radio" name="lrange"  value="b" <?php print $lb; ?>/></td>
  </tr>
</table>

<br />
<b>Chose  where you want to apply this effect:</b><br />
<table width=" " cellspacing="0" cellpadding="0">
<tr>
  <th align="right">Page background&nbsp;</th>
  <th>&nbsp;Pictures in page</th><tr>
  <tr><td valign="top" align="right"><?php print $op_pages; ?></td><td valign="top"><?php print $op_picpages; ?></td></tr>
</table>


<p class="submit">
<input type="submit" name="Submit" class="button-primary" value="<?php esc_attr_e('Save Changes') ?>" />
</p>

</form>



 
<?php
	if($newvals){
		if(!$errmsg){
			?>
			<div class="updated"><p><strong>settings saved</strong></p></div>
			<?php
		}
		else{
			?>
			<div class="updated"><p style="color:red"><strong>Sorry<br /><?php print $errmsg; ?> -  No changes made.</strong></p></div>
			<?php
        } 
	}
	?></div>
<?php }