// JavaScript Document
// rev 1.0
/**
* The two conversion procedures are from http://stackoverflow.com/questions/2353211/hsl-to-rgb-color-conversion

/*
 * Converts an RGB color value to HSL. Conversion formula
 * adapted from http://en.wikipedia.org/wiki/HSL_color_space.
 * Assumes r, g, and b are contained in the set [0, 255] and
 * returns h, s, and l in the set [0, 1].

 
 * @param   Number  r       The red color value
 * @param   Number  g       The green color value
 * @param   Number  b       The blue color value
 * @return  Array           The HSL representation
 
 	('wordpool_' added to avoid possible function name clash)
 */
function wordpool_rgbToHsl(r, g, b){
    r /= 255, g /= 255, b /= 255;
    var max = Math.max(r, g, b), min = Math.min(r, g, b);
    var h, s, l = (max + min) / 2;

    if(max == min){
        h = s = 0; // achromatic
    }else{
        var d = max - min;
        s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
        switch(max){
            case r: h = (g - b) / d + (g < b ? 6 : 0); break;
            case g: h = (b - r) / d + 2; break;
            case b: h = (r - g) / d + 4; break;
        }
        h /= 6;
    }

    return [h, s, l];
}
/**
 * Converts an HSL color value to RGB. Conversion formula
 * adapted from http://en.wikipedia.org/wiki/HSL_color_space.
 * Assumes h, s, and l are contained in the set [0, 1] and
 * returns r, g, and b in the set [0, 255].
 *
 * @param   Number  h       The hue
 * @param   Number  s       The saturation
 * @param   Number  l       The lightness
 * @return  Array           The RGB representation
 */
 
//=================================================================== 
function wordpool_hslToRgb(h, s, l){
    var r, g, b;

    if(s == 0){
        r = g = b = l; // achromatic
    }else{
        var hue2rgb = function hue2rgb(p, q, t){
            if(t < 0) t += 1;
            if(t > 1) t -= 1;
            if(t < 1/6) return p + (q - p) * 6 * t;
            if(t < 1/2) return q;
            if(t < 2/3) return p + (q - p) * (2/3 - t) * 6;
            return p;
        }

        var q = l < 0.5 ? l * (1 + s) : l + s - l * s;
        var p = 2 * l - q;
        r = hue2rgb(p, q, h + 1/3);
        g = hue2rgb(p, q, h);
        b = hue2rgb(p, q, h - 1/3);
    }

    return [Math.round(r * 255), Math.round(g * 255), Math.round(b * 255)];
}
//====================================================================
function wordpool_nextColour(useh, uses, usel, h,s,l, hdelta, sdelta, ldelta, sstart, srange,  lstart, lrange, bg, pic, loop){
	if(useh){
		h+=hdelta;
		if(h>1){
			h=0;
		}
	}
	
	
	if(uses){
		s+=sdelta
		if(s>1){
			s=1;
			sdelta=-sdelta;
		}
		if(s<0){
			s=0;
			sdelta=-sdelta
		}
		if(srange=="u" && s<sstart) {
			sdelta=-sdelta;
		}
		if(srange=="d" && s>sstart) {
			sdelta=-sdelta;
		}
	}
		
	if(usel){
	l+=ldelta
		if(l>1){
			l=1;
			ldelta=-ldelta;
		}
		if(l<0){
			l=0;
			ldelta=-ldelta
		}
		if(lrange=="u" && l<lstart) {
			ldelta=-ldelta;
		}
		if(lrange=="d" && l>lstart) {
			ldelta=-ldelta;
		}
	}

	var a=wordpool_hslToRgb(h, s, l);
	var r=a[0].toString(16);
	var g=a[1].toString(16);
	var b=a[2].toString(16);
	if(r.length==1){r='0'+r}
	if(g.length==1){g='0'+g}
	if(b.length==1){b='0'+b}
	var strcol='#' +r+g+b;

	
	if(bg==1){
		document.getElementsByTagName('body')[0].style.backgroundColor=strcol;
	}
	if(pic==1){
		var images=document.getElementsByTagName('img');
		for(var i=0; i<images.length; i++){
			document.getElementsByTagName('img')[i].style.backgroundColor=strcol;
		}
	}
	if(loop==0 || loop==1){
	//alert("loopinfo: color= " + strcol + "\nuseh= " + useh + "\nh=" + h + "\ns=" + s +"\nl=" + l + "\nhdelta= " +hdelta +"\nsdelta= " +sdelta + "\nldelta= " +ldelta 
	//	+ "\nbg= " + bg + " pic=" + pic)
	}
	if(loop>205){
			loop=0;
	}
	loop++;
	setTimeout(function(){
		wordpool_nextColour(useh, uses, usel, h,s,l, hdelta, sdelta, ldelta, sstart, srange, lstart, lrange, bg, pic, loop)
	},45)
}

//=============================================================================
 jQuery(document).ready( function() {
	//alert('Here we are');
	if(document.getElementById('wordpool-background-info')){
		wordpool_list=document.getElementById('wordpool-background-info').innerHTML;
			//		We need to use the values to calculate the starting hsl.
			//		Thereafter we will use 'next colour()' to shift the h value round the colour wheel
			//		the sdelta and ldelta to move up and down the saturation or lighness axes if
			//		we need to do so.	
		
		//alert(wordpool_list);
		
		wordpool_options=wordpool_list.split(',')
		// We need useh, uses, usel, h,s,l, hdelta, sdelta, ldelta, sstart, srange,  lstart, ldrn. loop
		// But with names that can't clash while in this globally available space
		wordpool_rgb  = wordpool_options[0]; // starting rgb
		wordpool_useh = wordpool_options[1]; // vary hue
		wordpool_uses = wordpool_options[2]; // vary saturation
		wordpool_usel = wordpool_options[3]; // vary lightness
		wordpool_hT   = wordpool_options[4]; // hue period
		wordpool_sT   = wordpool_options[5]; // saturation period
		wordpool_lT   = wordpool_options[6]; // lightness period
		wordpool_srange = wordpool_options[7]; // up, down or both for saturation variation
		wordpool_lrange = wordpool_options[8]; // up, down or both for lightness variation
		wordpool_bg     = wordpool_options[9]; // change the body background (1=yes)
		wordpool_pic    = wordpool_options[10]; //change the picture background (1=yes)
		
		wordpool_r=parseInt(wordpool_rgb.substring(0,2),16);  //red as hex
		wordpool_g=parseInt(wordpool_rgb.substring(2,4),16);  //green as hex
		wordpool_b=parseInt(wordpool_rgb.substring(4,6),16);  //blue as hex
		
		wordpool_hsl = wordpool_rgbToHsl(wordpool_r, wordpool_g, wordpool_b);  //hsl value of colour as array
		wordpool_hslh = wordpool_hsl[0];	//hue
		wordpool_hsls = wordpool_hsl[1];	//saturation
		wordpool_hsll = wordpool_hsl[2];	//lightness
		//alert(wordpool_useh + " - " + wordpool_uses + " - " + wordpool_usel)
		if(wordpool_useh==1 || wordpool_uses==1 || wordpool_usel==1){   // only do the rest if we're turned on with times
			// Calculate the amount to vary hsl each 45 milisecs
			wordpool_hdelta=0 //default
			if(wordpool_hT){
				wordpool_hdelta=.045/wordpool_hT;  
			}
			else{
				wordpool_hdelta=.0031
			}
			
			wordpool_srange='b'; //default
			wordpool_sdelta=0;    //default
			if(wordpool_sT){
				if(wordpool_srange=="d"){
					wordpool_sdelta=.09*wordpool_hsls/wordpool_sT;
				}
				if(wordpool_srange=="u"){
					wordpool_sdelta=.09*(1-wordpool_hsls)/wordpool_sT;
				}
				if(wordpool_srange=="b"){
					wordpool_sdelta=.09/wordpool_sT;
				}
			}
			
			wordpool_lrange='b';  //default
			wordpool_ldelta=0; //default
			if(wordpool_lT){
				if(wordpool_lrange=="d"){
					wordpool_ldelta=.09*wordpool_hsll/wordpool_lT;
				}
				if(wordpool_lrange=="u"){
					wordpool_ldelta=.09*(1-wordpool_hsll)/wordpool_lT;
				}
				if(wordpool_lrange=="b"){
					wordpool_ldelta=.09/wordpool_lT;
				}
			}
			
			wordpool_nextColour(wordpool_useh, wordpool_uses, wordpool_usel, 
							wordpool_hslh, wordpool_hsls, wordpool_hsll,
							wordpool_hdelta, wordpool_sdelta, wordpool_ldelta,
							wordpool_hsls, wordpool_srange,
							wordpool_hsll, wordpool_lrange,
							wordpool_bg, wordpool_pic,
							0);
		}
	}
 })
 
 